evenness<-function(x){
if(ncol(as.matrix(x))==1){
S<-length(x[x!=0])
J<-SW.index(x)/log(S)
}
if(ncol(as.matrix(x))>1){
Hs<-SW.index(x)
Hmax<-max(Hs[!is.na(Hs)&!is.nan(Hs)])
J<-Hs/Hmax
}
J
}
